@@ -81,6 +81,21 @@
 plot_radar <- function(risk_scores, aggregated_scores,
   type = "combined", pathway = "combined") {
 
+  ### check if suggested packages are installed: 
+  if(!requireNamespace(c("ggnewscale"), quietly = TRUE)){
+    stop(
+      "Package \"ggnewscale\" must be installed to use this function.",
+      call. = FALSE
+    )
+  }
+  if(!requireNamespace(c("ggplot2"), quietly = TRUE)){
+    stop(
+      "Package \"ggplot2\" must be installed to use this function.",
+      call. = FALSE
+    )
+  }
+
+  
   multi_press <- aggregated_scores$multi_pressure_risk
   multi_ind <- aggregated_scores$multi_indicator_risk
   system_risk <- aggregated_scores$ecosystem_risk
@@ -217,8 +232,8 @@ plot_radar <- function(risk_scores, aggregated_scores,
                                       paste0("\u00B1 ", plot_range[2]/4*3), paste0("\u00B1 ", plot_range[2]/4*4)),
                             color = "grey40") +
           # Convert it to a pie
-          # ggplot2::coord_polar() +
-          geomtextpath::coord_curvedpolar() +
+           ggplot2::coord_radial() +
+          #geomtextpath::coord_curvedpolar() +
 
           # Modify the theme
           ggplot2::labs(
@@ -315,8 +330,8 @@ plot_radar <- function(risk_scores, aggregated_scores,
             colour = col_multi_press, size = 4) +
 
           # Convert it to a pie
-          # ggplot2::coord_polar() +
-          geomtextpath::coord_curvedpolar() +
+          ggplot2::coord_radial() +
+          # geomtextpath::coord_curvedpolar() +
 
           # Modify the theme
           ggplot2::labs(title = paste0(indicators[i], ", ", status_helper, ", ", pathway_helper),
